@@ -9,8 +9,6 @@ package Archive::BagIt::Role::Algorithm;
 use Moose::Role;
 with 'Archive::BagIt::Role::Plugin';
 
-use Data::Printer;
-
 has 'name' => (
     is => 'ro',
 );
@@ -18,23 +16,23 @@ has 'name' => (
 
 sub get_hash_string {
     my ($self, $fh) = @_;
+    return;
 }
 
 sub verify_file {
     my ($self, $fh) = @_;
+    return;
 }
 
 sub register_plugin {
     my ($class, $bagit) =@_;
-    
     my $self = $class->new({bagit=>$bagit});
-
     my $plugin_name = $self->plugin_name;
-    #p ($self);
     $self->bagit->plugins( { $plugin_name => $self });
     $self->bagit->algos( {$self->name => $self });
+    return 1;
 }
-
+no Moose;
 1;
 
 __END__
@@ -49,7 +47,7 @@ Archive::BagIt::Role::Algorithm - A role that defines the interface to a hashing
 
 =head1 VERSION
 
-version 0.053.3
+version 0.055
 
 =head1 AVAILABILITY
 
@@ -59,13 +57,13 @@ site near you, or see L<https://metacpan.org/module/Archive::BagIt/>.
 
 =head1 SOURCE
 
-The development version is on github at L<https://github.com/rjeschmi/Archive-BagIt>
-and may be cloned from L<git://github.com/rjeschmi/Archive-BagIt.git>
+The development version is on github at L<https://github.com/Archive-BagIt>
+and may be cloned from L<git://github.com/Archive-BagIt.git>
 
 =head1 BUGS AND LIMITATIONS
 
 You can make new bug reports, and view existing ones, through the
-web interface at L<https://github.com/rjeschmi/Archive-BagIt/issues>.
+web interface at L<http://rt.cpan.org>.
 
 =head1 AUTHOR
 
@@ -73,7 +71,7 @@ Rob Schmidt <rjeschmi@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Rob Schmidt and William Wueppelmann.
+This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
